@@ -1,4 +1,4 @@
-# Copyright 2017 Red Hat, Inc.
+# Copyright 2017-2020 Red Hat, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -133,16 +133,19 @@ class NeutronApi(object):
             self, name, localnet=None, vlan=None, mtu=None,
             port_security_enabled=None
     ):
-        if localnet:
-            return self._add_localnet_network(
-                name, localnet, vlan, mtu, port_security_enabled
-            )
-        else:
-            return self._get_network(
-                self._create_network(name, mtu, port_security_enabled)
-            )
+        with self.tx_manager.transaction() as tx:
+            if localnet:
+                network_id = self._add_localnet_network(
+                    name, localnet, vlan, mtu, port_security_enabled,
+                    transaction=tx
+                )
+            else:
+                network_id = self._create_network(
+                    name, tx, mtu, port_security_enabled
+                )
+        return self._get_network(self.ovn_north.get_ls(ls_id=network_id))
 
-    def _create_network(self, name, mtu=None, port_security=None):
+    def _create_network(self, name, transaction, mtu=None, port_security=None):
         external_ids_dict = {NetworkMapper.OVN_NETWORK_NAME: name}
         if mtu is not None:
             external_ids_dict[NetworkMapper.OVN_MTU] = str(mtu)
@@ -151,25 +154,33 @@ class NeutronApi(object):
             else default_port_security_enabled()
         )
         name = u'ovirt-{name}-{gen_id}'.format(name=name, gen_id=uuid.uuid4())
-        return self.ovn_north.add_ls(
-            name=name,
-            external_ids=self._generate_external_ids({}, **external_ids_dict)
+        transaction.add(
+            self.ovn_north.add_ls(
+                name=name, external_ids=self._generate_external_ids(
+                    {}, **external_ids_dict
+                )
+            )
         )
+        return name
 
     @staticmethod
     def _generate_external_ids(current_external_ids, **kwargs):
         return dict(current_external_ids, **kwargs)
 
     def _add_localnet_network(
-            self, name, localnet, vlan, mtu, port_security_enabled
+            self, name, localnet, vlan, mtu, port_security_enabled, transaction
     ):
-        network = self._create_network(name, mtu, port_security_enabled)
-        localnet_port = self._create_port(
-            ovnconst.LOCALNET_SWITCH_PORT_NAME, str(network.uuid)
+        network_uuid = self._create_network(
+            name, transaction, mtu, port_security_enabled
         )
-        self._set_port_localnet_values(localnet_port, localnet, vlan)
-        updated_network = self.ovn_north.get_ls(ls_id=str(network.uuid))
-        return self._get_network(updated_network)
+        localnet_port = self._create_port(
+            ovnconst.LOCALNET_SWITCH_PORT_NAME, network_uuid,
+            transaction=transaction
+        )
+        transaction.add(
+            self._set_port_localnet_values(localnet_port, localnet, vlan)
+        )
+        return network_uuid
 
     @NetworkMapper.validate_update
     @NetworkMapper.map_from_rest
@@ -182,11 +193,16 @@ class NeutronApi(object):
             mtu=None,
             port_security_enabled=None
     ):
-        self._update_network_data(network_id, name, mtu, port_security_enabled)
-        self._update_localnet_on_network(network_id, localnet, vlan)
+        with self.tx_manager.transaction() as tx:
+            self._update_network_data(
+                network_id, name, mtu, port_security_enabled, tx
+            )
+            self._update_localnet_on_network(network_id, localnet, vlan, tx)
         return self.get_network(network_id)
 
-    def _update_network_data(self, network_id, name, mtu, port_security):
+    def _update_network_data(
+            self, network_id, name, mtu, port_security, transaction
+    ):
         current_external_ids = self.ovn_north.get_ls(
             ls_id=network_id
         ).external_ids
@@ -206,27 +222,38 @@ class NeutronApi(object):
             current_external_ids,
             **relevant_external_ids
         )
-        self.ovn_north.create_ovn_update_command(
-            ovnconst.TABLE_LS, network_id).add(
-            ovnconst.ROW_LS_EXTERNAL_IDS,
-            new_external_ids
-        ).execute()
+        transaction.add(
+            self.ovn_north.create_ovn_update_command(
+                ovnconst.TABLE_LS, network_id
+            ).add(
+                ovnconst.ROW_LS_EXTERNAL_IDS,
+                new_external_ids
+            ).build_command()
+        )
         if mtu:
-            self._update_networks_mtu(network_id, mtu)
+            self._update_networks_mtu(network_id, mtu, transaction)
 
-    def _update_localnet_on_network(self, network_id, localnet, vlan):
+    def _update_localnet_on_network(
+            self, network_id, localnet, vlan, transaction
+    ):
         network = self.ovn_north.get_ls(ls_id=network_id)
         localnet_port = self._get_localnet_lsp(network)
         if localnet:
             if not localnet_port:
                 localnet_port = self._create_port(
-                    ovnconst.LOCALNET_SWITCH_PORT_NAME, str(network.uuid))
-            self._set_port_localnet_values(localnet_port, localnet, vlan)
+                    ovnconst.LOCALNET_SWITCH_PORT_NAME, str(network.uuid),
+                    transaction=transaction
+                )
+            transaction.add(
+                self._set_port_localnet_values(localnet_port, localnet, vlan)
+            )
         elif localnet_port:
-            self.ovn_north.remove_lsp(str(localnet_port.uuid))
+            self.ovn_north.remove_lsp(
+                str(localnet_port.uuid), transaction=transaction
+            )
 
     def _set_port_localnet_values(self, port_id, localnet, vlan):
-        self.ovn_north.create_ovn_update_command(
+        return self.ovn_north.create_ovn_update_command(
             ovnconst.TABLE_LSP, port_id
         ).add(
             ovnconst.ROW_LSP_ADDRESSES,
@@ -236,22 +263,24 @@ class NeutronApi(object):
             {ovnconst.LSP_OPTION_NETWORK_NAME: localnet}
         ).add(
             ovnconst.ROW_LSP_TYPE, ovnconst.LSP_TYPE_LOCALNET
-        ).add(ovnconst.ROW_LSP_TAG_REQUEST, vlan).execute()
+        ).add(ovnconst.ROW_LSP_TAG, vlan).build_command()
 
-    def _update_networks_mtu(self, network_id, mtu):
+    def _update_networks_mtu(self, network_id, mtu, transaction=None):
         subnet = self.ovn_north.get_dhcp(ls_id=network_id)
         old_mtu = self._get_subnet_mtu(subnet)
         if subnet and old_mtu != mtu:
-            self.ovn_north.create_ovn_update_command(
-                ovnconst.TABLE_DHCP_Options, subnet.uuid
-            ).add(
-                ovnconst.ROW_DHCP_OPTIONS
-                if ip_utils.is_subnet_ipv4(subnet)
-                else ovnconst.ROW_DHCP_EXTERNAL_IDS,
-                {SubnetMapper.OVN_DHCP_MTU: str(mtu)}
-            ).execute()
+            transaction.add(
+                self.ovn_north.create_ovn_update_command(
+                    ovnconst.TABLE_DHCP_Options, subnet.uuid
+                ).add(
+                    ovnconst.ROW_DHCP_OPTIONS
+                    if ip_utils.is_subnet_ipv4(subnet)
+                    else ovnconst.ROW_DHCP_EXTERNAL_IDS,
+                    {SubnetMapper.OVN_DHCP_MTU: str(mtu)}
+                ).build_command()
+            )
             if ip_utils.is_subnet_ipv6(subnet):
-                self._update_ipv6_subnet_lrp_mtu(subnet, str(mtu))
+                self._update_ipv6_subnet_lrp_mtu(subnet, str(mtu), transaction)
 
     @staticmethod
     def _get_subnet_mtu(subnet):
@@ -261,18 +290,20 @@ class NeutronApi(object):
             else subnet.external_ids.get(SubnetMapper.OVN_DHCP_MTU)
         ) if subnet else None
 
-    def _update_ipv6_subnet_lrp_mtu(self, subnet, mtu):
+    def _update_ipv6_subnet_lrp_mtu(self, subnet, mtu, transaction):
         impacted_lrp = self.ovn_north.get_lrp_by_subnet(subnet)
         if impacted_lrp:
-            self._update_ipv6_lrp_mtu(impacted_lrp, subnet, mtu)
+            transaction.add(
+                self._update_ipv6_lrp_mtu(impacted_lrp, subnet, mtu)
+            )
 
     def _update_ipv6_lrp_mtu(self, router_port, subnet, mtu):
-        self.ovn_north.create_ovn_update_command(
+        return self.ovn_north.create_ovn_update_command(
             ovnconst.TABLE_LRP, self.ovn_north.get_lrp_id(router_port)
         ).add(
             ovnconst.ROW_LRP_IPV6_RA_CONFIGS,
             self._build_ra_config_dict(subnet, mtu)
-        ).execute()
+        ).build_command()
 
     def delete_network(self, network_id):
         network = self.ovn_north.get_ls(ls_id=network_id)
@@ -283,13 +314,16 @@ class NeutronApi(object):
             self._get_localnet_lsp(network)
         )
 
-        subnets = self.ovn_north.list_dhcp()
-        for subnet in subnets:
-            subnet_network_id = subnet.external_ids.get('ovirt_network_id')
-            if subnet_network_id:
-                if network_id == subnet_network_id:
-                    self.ovn_north.remove_dhcp_options(subnet.uuid)
-        self.ovn_north.remove_ls(ls_id=network_id)
+        with self.tx_manager.transaction() as tx:
+            subnets = self.ovn_north.list_dhcp()
+            for subnet in subnets:
+                subnet_network_id = subnet.external_ids.get('ovirt_network_id')
+                if subnet_network_id:
+                    if network_id == subnet_network_id:
+                        self.ovn_north.remove_dhcp_options(
+                            subnet.uuid, transacion=tx
+                        )
+            tx.add(self.ovn_north.remove_ls(ls_id=network_id))
 
     def _get_localnet_lsp(self, ls):
         for lsp in ls.ports:
@@ -483,10 +517,7 @@ class NeutronApi(object):
                 mac += ' ' + self._get_port_addesses_suffix(
                     network_id, fixed_ips)
             else:
-                self.ovn_north.clear_row_column(
-                    ovnconst.TABLE_LSP, port_id,
-                    ovnconst.ROW_LSP_DHCPV4_OPTIONS
-                )
+                db_set_command.add(ovnconst.ROW_LSP_DHCPV4_OPTIONS, '')
             db_set_command.add(ovnconst.ROW_LSP_ADDRESSES, [mac])
         return db_set_command
 
@@ -602,7 +633,7 @@ class NeutronApi(object):
     def _create_port(self, name, network_id, transaction=None):
         generated_id = str(uuid.uuid4())
         self.ovn_north.add_lsp(
-            generated_id, name, network_id, transaction
+            generated_id, name, network_id, transaction=transaction
         )
         return generated_id
 
